def checkTotle(xmlUrl,expertCouont):
    flag = True
    return (False, {"与期望结果存在差异": expertCouont}) if flag else (True, "校验期望结果包含校验通过")


def main():
    code,message = checkTotle("http://XXXX",20)
    print(code)
    print(message)

if __name__ == '__main__':
    main()



from setuptools import setup, find_packages

setup(
    name='smartfeedabcdefg',
    version='1.0.0',
    description='用于smartfeed和流量渠道自动化测试工具包',
    author='zhouyanhui',
    packages=find_packages(),
    install_requires=[
        # List your package's dependencies here
        # TODO
    ],
)
